@@ -61,15 +61,12 @@ class RestApiClientLocalRecipesIndex:
     def __init__(self, remote, home_folder):
         self._remote = remote
         local_recipes_index_path = HomePaths(home_folder).local_recipes_index_path
-        local_recipes_index_path = os.path.join(local_recipes_index_path, remote.name)
-        local_recipes_index_path = os.path.join(local_recipes_index_path, ".conan")
+        local_recipes_index_path = os.path.join(local_recipes_index_path, remote.name, ".conan")
         repo_folder = self._remote.url
 
-        from conan.internal.conan_app import ConanApp
-        from conan.api.conan_api import ConanAPI
-        conan_api = ConanAPI(local_recipes_index_path)
-        self._app = ConanApp(conan_api)
-        self._hook_manager = HookManager(HomePaths(conan_api.home_folder).hooks_path)
+        from conan.internal.conan_app import LocalRecipesIndexApp
+        self._app = LocalRecipesIndexApp(local_recipes_index_path)
+        self._hook_manager = HookManager(HomePaths(local_recipes_index_path).hooks_path)
         self._layout = _LocalRecipesIndexLayout(repo_folder)
 
     def call_method(self, method_name, *args, **kwargs):
@@ -137,11 +134,6 @@ class RestApiClientLocalRecipesIndex:
 
     def get_recipe_revision_reference(self, ref):
         new_ref = self._export_recipe(ref)
-        if new_ref != ref:
-            ConanOutput().warning(f"A specific revision '{ref.repr_notime()}' was requested, but it "
-                                  "doesn't match the current available revision in source. The "
-                                  "local-recipes-index can't provide a specific revision")
-            raise RecipeNotFoundException(ref)
         return new_ref
 
     def get_package_revision_reference(self, pref):
@@ -165,6 +157,13 @@ class RestApiClientLocalRecipesIndex:
             sys.stderr = original_stderr
             ConanOutput(scope="local-recipes-index").debug(f"Internal export for {ref}:\n"
                                                            f"{textwrap.indent(export_err, '    ')}")
+        if new_ref.user != ref.user or new_ref.channel != ref.channel:
+            raise RecipeNotFoundException(ref)
+        if ref.revision is not None and new_ref.revision != ref.revision:
+            ConanOutput().warning(f"A specific revision '{ref.repr_notime()}' was requested, but it "
+                                  "doesn't match the current available revision in source. The "
+                                  "local-recipes-index can't provide a specific revision")
+            raise RecipeNotFoundException(ref)
         return new_ref
 
     @staticmethod
